==> haskell-errors-2.1.1-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-errors/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.1.1
id: errors-2.1.1-b37eb483a10c58cd16bef6d935bee791
key: error_BxFyNMjIfYVI3NqJu1HRjX
license: BSD3
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/errors-2.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/errors-2.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/errors-2.1.1
hs-libraries: HSerrors-2.1.1-BxFyNMjIfYVI3NqJu1HRjX
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    safe-0.3.9-b613242f536083d5bb04920ede356aea
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    unexceptionalio-0.3.0-59e0425255963cd7df216a385ee18633
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-errors-2.1.2-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-errors/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.1.2
id: errors-2.1.2-05a7a3b6d680c93556c3c86284da4ff2
key: error_HUqx9vmMhwJKdeqgjQTiZV
license: BSD3
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/errors-2.1.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/errors-2.1.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/errors-2.1.2
hs-libraries: HSerrors-2.1.2-HUqx9vmMhwJKdeqgjQTiZV
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    safe-0.3.9-b613242f536083d5bb04920ede356aea
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    unexceptionalio-0.3.0-59e0425255963cd7df216a385ee18633
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
